package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcZfwz;
import org.apache.ibatis.annotations.Param;

/**
 * 政府网站Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcZfwzMapper 
{
    /**
     * 查询政府网站
     * 
     * @param id 政府网站主键
     * @return 政府网站
     */
    public TcZfwz selectTcZfwzById(Long id);

    /**
     * 查询政府网站列表
     * 
     * @param tcZfwz 政府网站
     * @return 政府网站集合
     */
    public List<TcZfwz> selectTcZfwzList(TcZfwz tcZfwz);

    /**
     * 新增政府网站
     * 
     * @param tcZfwz 政府网站
     * @return 结果
     */
    public int insertTcZfwz(TcZfwz tcZfwz);

    /**
     * 修改政府网站
     * 
     * @param tcZfwz 政府网站
     * @return 结果
     */
    public int updateTcZfwz(TcZfwz tcZfwz);

    /**
     * 删除政府网站
     * 
     * @param id 政府网站主键
     * @return 结果
     */
    public int deleteTcZfwzById(Long id);

    /**
     * 批量删除政府网站
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcZfwzByIds(Long[] ids);


    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
