package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcZdqyml;
import com.ruoyi.tcZz.domain.TcZfwz;
import com.ruoyi.tcZz.service.ITcZfwzService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 政府网站Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "政府网站")
@RequestMapping("/tcZz/networkSecurity/zfwz")
public class TcZfwzController extends BaseController {
    @Autowired
    private ITcZfwzService tcZfwzService;

    /**
     * 查询政府网站列表
     */
    @ApiOperation(value = "查询政府网站列表", response = TcZfwz.class)
    @GetMapping("/list")
    public TableDataInfo list(TcZfwz tcZfwz) {
        startPage();
        List<TcZfwz> list = tcZfwzService.selectTcZfwzList(tcZfwz);
        return getDataTable(list);
    }

    /**
     * 导出政府网站列表
     */
    @ApiOperation(value = "导出政府网站列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZfwz tcZfwz) {
        List<TcZfwz> list = tcZfwzService.selectTcZfwzList(tcZfwz);
        ExcelUtil<TcZfwz> util = new ExcelUtil<TcZfwz>(TcZfwz.class);
        util.exportExcel(response, list, "政府网站数据");
    }

    /**
     * 获取政府网站详细信息
     */
    @ApiOperation(value = "获取政府网站详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcZfwzService.selectTcZfwzById(id));
    }

    /**
     * 新增政府网站
     */
    @ApiOperation(value = "新增政府网站")
    @PostMapping
    public AjaxResult add(@RequestBody TcZfwz tcZfwz) {
        return toAjax(tcZfwzService.insertTcZfwz(tcZfwz));
    }

    /**
     * 修改政府网站
     */
    @ApiOperation(value = "修改政府网站")
    @PutMapping
    public AjaxResult edit(@RequestBody TcZfwz tcZfwz) {
        return toAjax(tcZfwzService.updateTcZfwz(tcZfwz));
    }

    /**
     * 删除政府网站
     */
    @ApiOperation(value = "删除政府网站")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcZfwzService.deleteTcZfwzByIds(ids));
    }



    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcZfwz> util = new ExcelUtil<TcZfwz>(TcZfwz.class);
        List<TcZfwz> tcZfwzList = util.importExcel(file.getInputStream());
        tcZfwzService.importUser(tcZfwzList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus,@RequestParam("ids") List<String> ids) {
        tcZfwzService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcZfwz> util = new ExcelUtil<TcZfwz>(TcZfwz.class);
        util.importTemplateExcel(response, " 政府网站");
    }
}
